/*
 * checkerberry test center - https://www.checkerberry.de
 *
 * Copyright (c) 2010 ConceptPeople consulting gmbh
 *
 * Lizenziert unter der EUPL, Version 1.1 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/software/page/eupl5
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.conceptpeople.checkerberry.web.example;

import org.junit.After;
import org.junit.Before;
import org.junit.Rule;

import de.conceptpeople.checkerberry.junit4.connector.MethodNameDeterminationRule;
import de.conceptpeople.checkerberry.web.environment.CheckerberryWeb;
import de.conceptpeople.checkerberry.web.environment.CheckerberryWebEnvironment;
import de.conceptpeople.checkerberry.web.environment.CheckerberryWebEnvironmentId;
import de.conceptpeople.checkerberry.web.environment.ContextProvider;
import de.conceptpeople.checkerberry.web.environment.DefaultWebConfiguration;
import de.conceptpeople.checkerberry.web.policy.DefaultNewBrowserInstancePolicy;
import de.conceptpeople.checkerberry.web.remote.RemoteControl;
import de.conceptpeople.checkerberry.web.remote.WebConfiguration;
import de.conceptpeople.checkerberry.web.remote.WebContext;

/**
 * Abstrakte Testklasse zur Kapselung genereller Aufgaben. Diese Klasse wird
 * sich in jedem Projekt unterscheiden. Der Vorteil ist allerdings, dass keine
 * Vererbung von Basisklassen erforderlich ist, sodass checkerberry web-Tests
 * mit anderen Tests kombiniert werden können, die bestimmte Superklassen
 * benötigen wie z.B. SpringBaseTestCase.
 */
public abstract class AbstractGuiTest implements ContextProvider {
    // CHECKSTYLE:OFF
    @Rule
    public MethodNameDeterminationRule rule = new MethodNameDeterminationRule();
    // CHECKSTYLE:ON

    private CheckerberryWebEnvironment environment;

    @Before
    public void setUp() {
        // Hole das Environment für diese Klasse
        DefaultWebConfiguration configuration = createWebConfiguration();
        updateConfiguration(configuration);

        environment = CheckerberryWeb.getInstance().getEnvironment(
                new CheckerberryWebEnvironmentId(getClass().getName()), configuration);
        environment.setUp(this);
    }

    @After
    public void tearDown() {
        environment.tearDown();
        environment = null;
    }

    /**
     * Erzeugt die checkerberry web-Konfiguration für den Test.
     *
     * @return erzeugte Konfiguration.
     */
    protected DefaultWebConfiguration createWebConfiguration() {
        return new DefaultWebConfiguration();
    }

    /**
     * Aktualisiert die checkerberry web-Konfiguration.
     *
     * @param configurationToUpdate
     *            zu aktualisierende Konfiguration.
     */
    protected void updateConfiguration(DefaultWebConfiguration configurationToUpdate) {
        // Ein Wert von -1 bedeutet, dass innerhalb einer Klasse für alle
        // Test-Methode die gleiche Browser-Instanz verwendet wird.
        DefaultNewBrowserInstancePolicy policy = new DefaultNewBrowserInstancePolicy();
        policy.setBrowserReuseCount(-1);

        configurationToUpdate.setNewBrowserInstancePolicy(policy);
    }

    /** {@inheritDoc}. */
    public RemoteControl getRemoteControl() {
        return environment.getRemoteControl();
    }

    /** {@inheritDoc}. */
    public WebContext getContext() {
        return environment.getContext();
    }

    /** {@inheritDoc}. */
    public WebConfiguration getConfiguration() {
        return getContext().getConfiguration();
    }
}
