/*
 * checkerberry test center - https://www.checkerberry.de
 *
 * Copyright (c) 2010 ConceptPeople consulting gmbh
 *
 * Lizenziert unter der EUPL, Version 1.1 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/software/page/eupl5
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.conceptpeople.checkerberry.web.example;

import org.junit.AfterClass;
import org.junit.BeforeClass;

/**
 * Abstrakte Testklasse die die Test-Web-Anwendung in einem In-Memory-Webserver
 * startet.
 * <p/>
 * Der Test-Web-Anwendung wird in dem Classpath unter
 * <code>lib/checkerberry-web-test-application.war</code> erwartet.
 */
public abstract class AbstractTestWebApplicationGuiTest extends AbstractGuiTest {

    /** Instanz des Jetty Webservers. */
    private static JettyServer webServer;

    /**
     * Instanziiert den Webserver. Diese Methode wird beim Start der Klasse
     * aufgerufen.
     * 
     * @throws Exception
     *             wenn der Webserver nicht gestartet werden konnte.
     */
    @BeforeClass
    public static void classSetUp() throws Exception {

        if (webServer == null) {

            webServer = new JettyServer("lib/checkerberry-web-test-application.war");
            webServer.start();
        }
    }

    /**
     * Beendet den Webserver. Diese Methode wird beim 'Beenden' der Klasse
     * aufgerufen.
     * 
     * @throws Exception
     *             wenn der Webserver nicht gestartet werden konnte.
     */
    @AfterClass
    public static void classTearDown() throws Exception {

        if (webServer != null) {
            webServer.stop();
            webServer = null;
        }
    }
}
