/*
 * checkerberry test center - https://www.checkerberry.de
 *
 * Copyright (c) 2010 ConceptPeople consulting gmbh
 *
 * Lizenziert unter der EUPL, Version 1.1 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/software/page/eupl5
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.conceptpeople.checkerberry.web.example.model;

import de.conceptpeople.checkerberry.web.environment.ContextProvider;
import de.conceptpeople.checkerberry.web.model.AbstractRemoteControlPage;

/**
 * Abstraktes Model für die Test-Web-Anwendung. Es ist generell sinnvoll, eigene
 * Basisklassen für {@link AbstractRemoteControlPage},
 * {@link de.conceptpeople.checkerberry.web.model.AbstractRemoteControlPortlet}
 * und {@link de.conceptpeople.checkerberry.web.model.RemoteControlComponent} zu
 * definieren. In diesen Basisklassen können generelle Methoden bereitgestellt
 * werden, die alle Seiten, Portlets oder Komponenten benötigen.
 */
public abstract class AbstractBasePage extends AbstractRemoteControlPage {

    /** Die Navigation wurde in ein eigenes Modell ausgelagert. */
    private Navigation navigation;
    /**
     * Über die Body-Id ist jede Seite eindeutig identifizierbar. Es ist
     * generell sehr sinnvoll, die Seiten eindeutig identifizieren zu können.
     * Dadurch wird das Testen der Navigation erheblich vereinfacht.
     */
    private String bodyId;

    /**
     * Erzeugt ein neues Model.
     *
     * @param contextProvider
     *            Provider für die gesamten Kontextinformationen.
     * @param bodyId
     *            Id des Body-Tags für diese Seite.
     */
    public AbstractBasePage(ContextProvider contextProvider, String bodyId) {
        super(contextProvider);

        this.bodyId = bodyId;

        navigation = new Navigation(contextProvider);
    }

    /**
     * Prüft, ob diese Seite aktuell dargestellt wird.
     *
     * @return <code>true</code>, wenn diese Seite aktuell dargestellt wird.<br/>
     *         <code>false</code>, sonst.
     */
    @SuppressWarnings("deprecation")
    public boolean isDisplayed() {
        return getRemoteControl().isElementPresent(bodyId);
    }

    public Navigation getNavigation() {
        return navigation;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    protected BaseComponent createComponentProxy(String elementLocator) {
        // Erzeugen der eigenen Basisklasse, um eigene Funktionen überall
        // verfügbar zu haben.
        return new BaseComponent(this, elementLocator);
    }

}
